pub enum JoinOutputSource {
Input(usize),
Cast {
input: usize,
ty: ColumnType,
},
Coalesce {
left: usize,
right: usize,
ty: ColumnType,
},
}Expand description
Source of one visible or hidden join-output identity.
Variants
Input(usize)
Reuse an existing logical input position without copying its value.
Cast
Apply an implicit binder-selected coercion to one input position.
Coalesce
SQL COALESCE(left::type, right::type) over two logical input
positions. This is required only for a merged column of FULL JOIN.