Module map_rows

Module map_rows 

Streaming whole-row mapping adapter.

Structs

MapRows
Apply a fallible mapping to each input row without changing batch backpressure or collecting the child relation.

Type Aliases

SharedRowMapper