Module project_set

Module project_set 

Streaming one-to-many projection (ProjectSet).

Structs

PhysicalProjectSet
Pulls physical input rows and expands each without crossing the named-row materialization boundary.
ProjectSet
Pulls input rows and expands each through a set-returning projection.

Traits

PhysicalSetProjector
Engine seam for set-returning projections that keep rows in their physical layout.
SetProjector
Engine seam for set-returning projection expressions.

Type Aliases

PhysicalProjectRows
Owned physical row stream produced for one input row without materializing named maps.
ProjectRows
Owned row stream produced for one input row.