Module projected_row

Module projected_row 

Borrowed positional rows produced directly by projected storage reads.

Structs

ProjectedRow
Concrete borrowed row passed from a projected source into an aggregate executor.

Enums

ProjectedValueSlot
Source of one logical value in a ProjectedRow.