pub enum ProjectedValueSlot {
Field(usize),
Extra(usize),
Missing,
}Expand description
Source of one logical value in a ProjectedRow.
Variants
Field(usize)
Borrowed value at this position in the storage projection.
Extra(usize)
Query-local value at this position in the extra-value slice.
Missing
A logical column that is absent from the projected source.
Implementations