Sort

Struct Sort 

pub struct Sort<'a> { /* private fields */ }

Implementations

Source

impl Sort<'static>

pub fn new( child: Box<dyn PhysicalOperator>, keys: Vec<SortKey>, params: Vec<SQLParam>, ) -> Self

pub fn with_keep( child: Box<dyn PhysicalOperator>, keys: Vec<SortKey>, params: Vec<SQLParam>, keep: usize, ) -> Self

Top-K variant: retain only the first keep rows of the sorted order. Uses a partial selection, so the cost is O(n + k log k) instead of O(n log n).

Source

impl<'a> Sort<'a>

pub fn with_evaluator( child: Box<dyn PhysicalOperator + 'a>, keys: Vec<SortKey>, evaluator: SharedExpressionEvaluator<'a>, ) -> Self

pub fn with_evaluator_and_work_mem( child: Box<dyn PhysicalOperator + 'a>, keys: Vec<SortKey>, evaluator: SharedExpressionEvaluator<'a>, work_mem_bytes: usize, ) -> Self

pub fn with_evaluator_and_keep( child: Box<dyn PhysicalOperator + 'a>, keys: Vec<SortKey>, evaluator: SharedExpressionEvaluator<'a>, keep: usize, ) -> Self