Window

Struct Window 

pub struct Window<'a> { /* private fields */ }

Implementations

Source

impl Window<'static>

pub fn new( child: Box<dyn PhysicalOperator>, spec: WindowSpec, functions: Vec<(String, WindowKind)>, params: Vec<SQLParam>, ) -> Self

pub fn new_with_work_mem( child: Box<dyn PhysicalOperator>, spec: WindowSpec, functions: Vec<(String, WindowKind)>, params: Vec<SQLParam>, work_mem_bytes: usize, ) -> Self

Source

impl<'a> Window<'a>

pub fn with_executor( child: Box<dyn PhysicalOperator + 'a>, output_schema: Vec<String>, executor: Box<dyn WindowExecutor + 'a>, ) -> Self

Construct a physical window operator backed by the engine’s complete frame and function implementation.

pub fn with_typed_executor( child: Box<dyn PhysicalOperator + 'a>, output_schema: Vec<String>, output_types: Vec<Option<ColumnType>>, executor: Box<dyn WindowExecutor + 'a>, ) -> Self

pub fn with_row_schema_executor( child: Box<dyn PhysicalOperator + 'a>, schema: RowSchema, executor: Box<dyn WindowExecutor + 'a>, ) -> Self

pub fn output_has_spilled(&self) -> bool

Whether final window rows exceeded their output budget and were written to disk during the current/most recent invocation.