SubqueryResult

Struct SubqueryResult 

pub struct SubqueryResult {
    pub columns: Vec<String>,
    pub rows: Box<dyn Iterator<Item = Result<OwnedPhysicalRow, SQLError>> + Send>,
}
Pull-based scalar-subquery result. Scalar, EXISTS, and IN consumers never need to materialize the complete child relation: they respectively inspect at most two rows, one row, or one row at a time.

Fields

columns: Vec<String>rows: Box<dyn Iterator<Item = Result<OwnedPhysicalRow, SQLError>> + Send>

Implementations

Source

impl SubqueryResult

pub fn from_rows(columns: Vec<String>, rows: Vec<ResultRow>) -> Self

pub fn into_scalar_value(self) -> Result<Value, SQLError>

pub fn into_exists(self) -> Result<bool, SQLError>

pub fn contains(self, needle: &Value) -> Result<Option<bool>, SQLError>