pub fn prepare_backward_scan<'a>(
operator: Box<dyn PhysicalOperator + 'a>,
) -> Box<dyn PhysicalOperator + 'a>Expand description
Materialize an operator only when it identifies its output as a safe semantic boundary.
pub fn prepare_backward_scan<'a>(
operator: Box<dyn PhysicalOperator + 'a>,
) -> Box<dyn PhysicalOperator + 'a>Materialize an operator only when it identifies its output as a safe semantic boundary.