pub struct HashJoin<'a> { /* private fields */ }Implementations
Sourceimpl<'a> HashJoin<'a>
impl<'a> HashJoin<'a>
pub fn new( left: Box<dyn PhysicalOperator + 'a>, right: Box<dyn PhysicalOperator + 'a>, kind: JoinKind, left_keys: Vec<ScalarExpr>, right_keys: Vec<ScalarExpr>, evaluator: SharedExpressionEvaluator<'a>, left_nulls: ResultRow, right_nulls: ResultRow, ) -> Self
pub fn new_with_work_mem( left: Box<dyn PhysicalOperator + 'a>, right: Box<dyn PhysicalOperator + 'a>, kind: JoinKind, left_keys: Vec<ScalarExpr>, right_keys: Vec<ScalarExpr>, evaluator: SharedExpressionEvaluator<'a>, left_nulls: ResultRow, right_nulls: ResultRow, work_mem_bytes: usize, ) -> Self
pub fn new_with_work_mem_and_predicate( left: Box<dyn PhysicalOperator + 'a>, right: Box<dyn PhysicalOperator + 'a>, kind: JoinKind, left_keys: Vec<ScalarExpr>, right_keys: Vec<ScalarExpr>, predicate: Option<ScalarExpr>, evaluator: SharedExpressionEvaluator<'a>, left_nulls: ResultRow, right_nulls: ResultRow, work_mem_bytes: usize, ) -> Self
Sourcepub fn try_new_with_work_mem_and_predicate(
left: Box<dyn PhysicalOperator + 'a>,
right: Box<dyn PhysicalOperator + 'a>,
kind: JoinKind,
left_keys: Vec<ScalarExpr>,
right_keys: Vec<ScalarExpr>,
predicate: Option<ScalarExpr>,
evaluator: SharedExpressionEvaluator<'a>,
left_nulls: ResultRow,
right_nulls: ResultRow,
work_mem_bytes: usize,
params: &[SQLParam],
) -> ExecResult<Self>
pub fn try_new_with_work_mem_and_predicate( left: Box<dyn PhysicalOperator + 'a>, right: Box<dyn PhysicalOperator + 'a>, kind: JoinKind, left_keys: Vec<ScalarExpr>, right_keys: Vec<ScalarExpr>, predicate: Option<ScalarExpr>, evaluator: SharedExpressionEvaluator<'a>, left_nulls: ResultRow, right_nulls: ResultRow, work_mem_bytes: usize, params: &[SQLParam], ) -> ExecResult<Self>
Construct a hash join while preparing supported residual predicates against its composite output schema. Parameters and constant LIKE patterns are folded exactly once before any candidate row is probed.
pub fn output_has_spilled(&self) -> bool
pub fn right_input_has_spilled(&self) -> bool
pub fn hash_index_has_spilled(&self) -> bool
pub fn builds_left_input(&self) -> bool