pub struct LateralJoin<'a> { /* private fields */ }Expand description
Streaming physical implementation of a SQL LATERAL join.
The left child is pulled in batches. The correlated right relation is evaluated once per left row, and produced rows are drained in bounded output batches instead of materialising the complete join result.
Implementations
Sourceimpl<'a> LateralJoin<'a>
impl<'a> LateralJoin<'a>
pub fn new( left: Box<dyn PhysicalOperator + 'a>, source: Box<dyn LateralSource + 'a>, kind: JoinKind, left_nulls: ResultRow, right_nulls: ResultRow, ) -> Self
pub fn new_with_right_schema( left: Box<dyn PhysicalOperator + 'a>, source: Box<dyn LateralSource + 'a>, kind: JoinKind, left_nulls: ResultRow, right_nulls: ResultRow, right_schema: RowSchema, ) -> Self