pub fn run_to_rows(
op: &mut dyn PhysicalOperator,
) -> ExecResult<(Vec<String>, Vec<ResultRow>)>Expand description
Run the operator and concatenate all output batches into a single flat row vector. The schema of the first batch is the result schema.