Streaming one-to-many projection (ProjectSet).
Structs
- Physical
Project Set - Pulls physical input rows and expands each without crossing the named-row materialization boundary.
- Project
Set - Pulls input rows and expands each through a set-returning projection.
Traits
- Physical
SetProjector - Engine seam for set-returning projections that keep rows in their physical layout.
- SetProjector
- Engine seam for set-returning projection expressions.
Type Aliases
- Physical
Project Rows - Owned physical row stream produced for one input row without materializing named maps.
- Project
Rows - Owned row stream produced for one input row.