pub struct SubqueryResult {
pub columns: Vec<String>,
pub rows: Box<dyn Iterator<Item = Result<OwnedPhysicalRow, SQLError>> + Send>,
}Expand description
Pull-based scalar-subquery result. Scalar, EXISTS, and IN consumers never need to materialize the complete child relation: they respectively inspect at most two rows, one row, or one row at a time.
Fields
columns: Vec<String>rows: Box<dyn Iterator<Item = Result<OwnedPhysicalRow, SQLError>> + Send>Implementations